@@ -2,7 +2,7 @@
  * Like what you see? Join us!
  * https://www.univention.com/about-us/careers/vacancies/
  *
- * Copyright 2020-2024 Univention GmbH
+ * Copyright 2020-2025 Univention GmbH
  *
  * https://www.univention.de/
  *
@@ -293,11 +293,6 @@ define([
 			this.notificationsPreview.addNotification(item);
 		},
 
-		_addPassiveNotification: function(item) {
-			// Please dont use this. This is for the summit only
-			this.notificationsContainer.addNotification(lang.clone(item));
-		},
-
 		addWarning: function(item) {
 			item.type = 'warning';
 			this.addNotification(item);
@@ -334,13 +329,6 @@ define([
 		});
 	};
 
-	NotificationsButton._addPassiveNotification = function(item) {
-		// Please dont use this. This is for the summit only
-		notificationsButtonCreatedDeferred.then(function(notificationsButton) {
-			notificationsButton._addPassiveNotification(item);
-		});
-	};
-
 	NotificationsButton.addWarning = function(item) {
 		notificationsButtonCreatedDeferred.then(function(notificationsButton) {
 			notificationsButton.addWarning(item);
